@@ -2,19 +2,14 @@ use std::{thread, time::Duration};
 
 use log::{debug, info, LevelFilter};
 use wolf_engine::{
-    initialize_logging, Context, ContextBuilder, EngineBuilder, OptionalTransition, RenderResult,
-    State, Transition,
+    initialize_logging, Context, Engine, OptionalTransition, RenderResult, State, Transition,
 };
 
 pub fn main() {
     initialize_logging(LevelFilter::Debug);
+    let state = MainState::new();
 
-    let starting_state = MainState::new();
-
-    let context = ContextBuilder::new().build();
-    EngineBuilder::with_default_scheduler()
-        .build(context)
-        .run(Box::from(starting_state));
+    Engine::new().run(Box::from(state));
 }
 
 pub struct MainState {
